@@ -24,7 +24,7 @@ class AriaService:
     def _process_aria_message(self, data, attribute=None):
         if 'detail' in data:
             detail = data['detail']
-            if attribute in detail:
+            if detail is not None and attribute in detail:
                 return detail.get(attribute)
             else:
                 return detail
@@ -65,7 +65,11 @@ class AriaService:
         data = res.json()
         if 'deltaToken' in data:
             self.delta_token = data.get('deltaToken')
-        return self._process_aria_message(data)
+        retval = self._process_aria_message(data)
+        if retval is None:
+            return []
+        else:
+            return retval
 
     def search_messages(self, data, timeout=None, limit=1000):
         timeout = self._timeout_default if timeout is None else timeout
@@ -102,7 +106,7 @@ class AriaService:
 
     def delete_message(self, id):
         payload = {"id": id}
-        res = requests.delete('{}/message'.format(self._base_url), json=payload, headers=self._headers)
+        res = requests.delete('{}/message'.format(self._base_url), params=payload, headers=self._headers)
         res.raise_for_status()
         return res
 
@@ -235,7 +239,7 @@ class AriaService:
 
         res = requests.delete(
             '{}/room/{}/member'.format(self._base_url, room_name),
-            json=data,
+            params=data,
             headers=self._headers,
             timeout=self._timeout_default
         )
