@@ -1,13 +1,11 @@
 #!/usr/bin/env python3
 # coding: utf8
 
-import logging
 import argparse
 import pathlib
 import re
 import importlib
 import sys
-import tempfile
 from time import sleep
 from requests.exceptions import HTTPError, RequestException, ConnectionError
 
@@ -87,7 +85,7 @@ class AriaBot:
                 except AttributeError as ae:
                     logging.warning('{} - ignoring entity'.format(ae.args[0], _ent['class']))
 
-    def _process_message(self, channel, msg, attachments, msg_text):
+    def _process_message(self, channel, msg, msg_id, attachments, msg_text):
         processed = False
         start = 0
         item = 1
@@ -98,7 +96,7 @@ class AriaBot:
             if not cmd_match:
                 break
             processed = True
-            cmd.do(match=cmd_match, message=msg, index=item, attachments=attachments, channel=channel)
+            cmd.do(match=cmd_match, message=msg, msg_id=msg_id, index=item, attachments=attachments, channel=channel)
             start = cmd_match.span()[1] + 1
             item = item + 1
         return processed
@@ -188,7 +186,12 @@ class AriaBot:
                     if 'channel' in msg:
                         channel = msg['channel']['name']
                     payload = msg['payload']
-                    processed_text = self._process_message(channel, payload.get('message', ''), msg['attachments'], msg_text)
+                    processed_text = self._process_message(
+                        channel,
+                        payload.get('message', ''),
+                        payload.get('messageId', ''),
+                        msg['attachments'], msg_text
+                    )
                     processed_entities = False
                     if 'data' in payload:
                         data = json.loads(payload['data'])
@@ -252,6 +255,7 @@ class AriaBotCommand:
         self.bot = kwargs['bot']
         self.pattern = kwargs['pattern']
         self.name = kwargs['name']
+        self.helptext = kwargs.get('helptext', None)
         self.config = kwargs['config']
         AriaBotCommand._commands.append(self)
 
@@ -266,6 +270,16 @@ class AriaBotCommand:
     def do(self, **kwargs):
         pass
 
+    def simple_help(self):
+        help_msg = SymphonyMessageML().bold('🤖: Here\'s a list of commands I understand')
+        help_msg.hrule()
+        for cmd in self._commands:
+            if cmd.helptext is not None:
+                help_msg = help_msg.bold(cmd.name).tail(' {} '.format(cmd.helptext)).tbreak()
+            else:
+                help_msg = help_msg.bold(cmd.name).tbreak()
+        return help_msg
+
 
 class AriaBotEntityHandler:
 
